@@ -5,6 +5,6 @@ from skyhawk.services import trainer
 @click.command()
 def cli():
 	'''Train skyhawk classifier on captured data'''
-	result = trainer.Facetrainer()
+	result = trainer.Facerunnner()
 	return result
 
